@@ -1,6 +1,8 @@
 import hmmhelper
+import demo
 from wrapper import forward
 from wrapper import backward
 from wrapper import posterior
 from wrapper import fwdbwd_alldisk
 from wrapper import fwdbwd_somedisk
+from wrapper import fwdbwd_nodisk
